@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -77,14 +77,15 @@ namespace Oxygen
             "(?:(\\d+),(\\d+),(\\d+)(?:,(\\d+))?)",
             G_REGEX_CASELESS, (GRegexMatchFlags)0, 0L );
 
-        GMatchInfo* matchInfo;
+        GMatchInfo* matchInfo(0L);
         g_regex_match( regex, value.c_str(), (GRegexMatchFlags)0, &matchInfo);
         const int matchCount( g_match_info_get_match_count( matchInfo ) );
         if( matchCount == 2 )
         {
 
             // convert to hex number
-            std::istringstream in( g_match_info_fetch( matchInfo, 1 ) );
+            gchar* matchedString( g_match_info_fetch( matchInfo, 1 ) );
+            std::istringstream in( matchedString );
             int colorValue = 0;
             in >> std::hex >> colorValue;
 
@@ -92,12 +93,15 @@ namespace Oxygen
             out.setGreen( double( (colorValue>>=8)&0xff)/255 );
             out.setRed( double( (colorValue>>=8)&0xff)/255 );
 
+            g_free( matchedString );
+
         } else if( matchCount >= 5 ) {
 
             for( int index = 0; index < matchCount-2; ++index )
             {
 
-                std::istringstream in( g_match_info_fetch( matchInfo, index+2 ) );
+                gchar* matchedString( g_match_info_fetch( matchInfo, index+2 ) );
+                std::istringstream in( matchedString );
                 int colorValue;
                 if( !(in >> colorValue) ) break;
 
@@ -106,6 +110,8 @@ namespace Oxygen
                 else if( index == 2 ) out.setBlue( double(colorValue)/255 );
                 else if( index == 3 ) out.setAlpha( double(colorValue)/255 );
 
+                g_free( matchedString );
+
             }
 
         }
